********************************************************************************
* NOTE FOR MAC USERS: Change the path to match your working directory. 

global path "[Insert Path Here]/Online Appendix Data and Code"
global temp "$path/Temp"
global output "$path/Output"

********************************************************************************

set more off
set type double

********************************************************************************

* Sum Stats

use "$temp/for sum stats", clear

* Create a dataset with both all and each invidividual group
gen collapse_group = group
append using "$temp/for sum stats"
replace collapse_group = "All" if collapse_group == ""

* Collape
gen N = 1
collapse (sum) N (mean) region_* gender_* race_* age_* sex_orien_* income_* mar_status_* educ_* pol_party_* vote_2012_*, by(collapse_group)

* Transpose
gen t = 1
reshape wide N region_* gender_* race_* age_* sex_orien_* income_* mar_status_* educ_* pol_party_* vote_2012_*, i(t) j(collapse_group) string
reshape long @ACE @ACF @ADE @ADF @BCE @BCF @BDE @BDF @All, i(t) j(variable) string

drop t
sort variable All

* This creates the body of Online Appendix Table 2
export excel "$output/no guns balance.xlsx", sheetreplace first(var) sheet("Sum Stats")


********************************************************************************

* F-test (LHS=treatments)

use "$temp/for sum stats", clear

tab group, gen(group_)

drop region_northeast gender_male  race_white age_24_or_less sex_orien_hetero income_0_24 mar_status_single educ_high_school pol_party_dem vote_2012_obama

* This creates F-tests in right column of Online Appendix Table 2
foreach n of numlist 1/8  {

	reg group_`n' region_* gender_* race_* age_* sex_orien_* income_* mar_status_* educ_* pol_party_* vote_2012_*
	outreg2 using "$output/Balance LHS_treatments 6_13_16.xls", excel dec(3) addstat(F test, e(F))
	di in red e(F)
	}

	
********************************************************************************

* F-test (LHS=demographic variables)

use "$temp/for sum stats", clear

encode group, gen(group_e)
drop sex_orien_other

* This creates F-tests in bottom row of Online Appendix Table 2
foreach v of varlist region_* gender_* race_* age_* sex_orien_* income_* mar_status_* educ_high_school educ_associates educ_bachelors educ_graduate pol_party_* vote_2012_*  {

	reg `v' i.group_e
	outreg2 using "$output/Balance LHS_demographics 6_13_16.xls", excel dec(3) addstat(F test, e(F))
	di in red e(p)
	}




